@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "wavedrom-mode" "0.1.1"
+(define-package "wavedrom-mode" "20250720.1337"
   "WaveDrom Integration."
   '((emacs "29.1"))
   :url "https://github.com/gmlarumbe/wavedrom-mode"
